from distutils.core import setup
setup(
        name='kgame',
        packages=['kgame'],
        version = '0.93',
        description = 'a kivy game engine',
        author = 'Zhao Chang',
        author_email='zhchang@gmail.com',
        url='https://github.com/zhchang/kgame',
        keywords = ['kivy','game engine'],
        classifiers = [])
